isOnPATH function

bool isOnPATH(
  1. String path
)

Tests if the given path is contained in the OS's PATH environment variable. An canonicalized match of path is made against each path on the OS's path. @Throwing(ArgumentError) @Throwing(MissingDependencyException)

Implementation

bool isOnPATH(String path) => Env().isOnPATH(path);