UserEnvironment class
Constructors
- UserEnvironment.preSudo({required String pathToHome})
- Creates a UserEnvironment from the SUDO env args that describe the pre-sudo user.
- UserEnvironment.save()
Properties
- dbusSessionBusAddress ↔ String?
-
The address of the user's D-Bus session.
latefinal
- gid ↔ int
-
we cache the real uid and gid
when we release privileges so we can restore them.
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathToHome ↔ String
-
The path to the original privileged users home dir.
latefinal
- pathToShell ↔ String?
-
latefinal
- pathToXdgRuntimeDirectory ↔ String?
-
The per-user runtime directory used by session services on Linux.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid ↔ int
-
latefinal
- username ↔ String
-
latefinal
Methods
-
build(
) → void - Build the user environment @Throwing(PosixException)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reorder(
bool condition(), void one(), void two()) → void -
If
conditionis true then we callonethentwo. Ifconditionis false then we calltwothenone. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited